@@ -1,3 +1,8 @@
+"""
+Mappings that tell the _JsonEngine the user facing attribute names and the
+steps needed to get there in a JSON dictionary
+"""
+
 from __future__ import annotations
 
 from abc import ABC
@@ -50,7 +55,7 @@ class _GeneralMapping(ABC):
     }
 
     @classmethod
-    def return_mapping(cls, keys: List[str] = [], exclude: List[str] = []) -> Dict[str, deque]:
+    def return_mapping(cls, keys: List[str] = None, exclude: List[str] = None) -> Dict[str, deque]:
         """
         Return key-directive pairs specified by key names. If no keys are
         specified, return all
@@ -65,11 +70,15 @@ class _GeneralMapping(ABC):
         directive_dict : Dict[str, deque]
             Dictionary of keys and their directives
         """
-        if type(keys) == str:
+        if keys is None:
+            keys = []
+        if exclude is None:
+            exclude = []
+        if isinstance(keys, str):
             keys = [keys]
-        if type(exclude) == str:
+        if isinstance(exclude, str):
             exclude = [exclude]
-            
+
         if not keys:
             keys = list(cls.mapping)
         if exclude:
@@ -86,7 +95,8 @@ class _PostMapping(_GeneralMapping):
         {
             "id": deque(["id"]),
             "shortcode": deque(["shortcode"]),
-            "dimensions": deque(["dimensions"]),
+            "height": deque(["height"]),
+            "width": deque(["width"]),
             "gating_info": deque(["gating_info"]),
             "fact_check_overall_rating": deque(["fact_check_overall_rating"]),
             "fact_check_information": deque(["fact_check_information"]),
@@ -113,12 +123,20 @@ class _PostMapping(_GeneralMapping):
             "viewer_in_photo_of_you": deque(["viewer_in_photo_of_you"]),
             "viewer_can_reshare": deque(["viewer_can_reshare"]),
             "video_url": deque(["video_url"]),
-            "has_audio": deque(["has_audio"])
+            "has_audio": deque(["has_audio"]),
+            "video_view_count": deque(["video_view_count"]),
+            "username": deque(["shortcode_media_owner_username"]),
+            "full_name": deque(["owner_full_name"])
+
         }
     )
 
     @classmethod
     def post_from_profile_mapping(cls):
+        """
+        Return the mapping needed for parsing a post's JSON data from the JSON
+        served back after requesting a Profile page.
+        """
         return {
             "id": deque(["id"]),
             "shortcode": deque(["shortcode"]),
@@ -139,6 +157,10 @@ class _PostMapping(_GeneralMapping):
 
     @classmethod
     def post_from_hashtag_mapping(cls):
+        """
+        Return the mapping needed for parsing a post's JSON data from the JSON
+        served back after requesting a Hashtag page.
+        """
         return {
             "comments_disabled": deque(["comments_disabled"]),
             "id": deque(["id"]),
@@ -218,6 +240,30 @@ class _HashtagMapping(_GeneralMapping):
         }
     )
 
+class _LocationMapping(_GeneralMapping):
+    """Mapping specific to Instagram profile pages"""
+
+    mapping = _GeneralMapping.return_mapping().copy()
+    mapping.update(
+        {
+            "id": deque(["id"]),
+            "name": deque(["name"]),
+            "has_public_page": deque(["has_public_page"]),
+            "latitude": deque(["lat"]),
+            "longitude": deque(["lng"]),
+            "slug": deque(["slug"]),
+            "blurb": deque(["blurb"]),
+            "website": deque(["website"]),
+            "phone": deque(["phone"]),
+            "primary_alias_on_fb": deque(["primary_alias_on_fb"]),
+            "stress_address": deque(["street_address"]),
+            "zip_code": deque(["zip_code"]),
+            "city_name": deque(["city_name"]),
+            "region_name": deque(["region_name"]),
+            "country_code": deque(["country_code"]),
+            "amount_of_posts": deque(["count"]),
+        }
+    )
 
 class _LoginMapping(_GeneralMapping):
     """Mapping specific to Instagram login page"""
@@ -251,4 +297,8 @@ class _MetaMapping:
 
     @classmethod
     def get_mapper(cls, page_type: str) -> MappingObject:
+        """
+        Return the appropriate mapper that corresponds to the page_type as
+        given in the requested Instagram JSON data
+        """
         return cls.str_to_mapper_obj[page_type]
