@@ -1,6 +1,11 @@
+"""
+Primary API scraper tools
+"""
+
 from instascrape.scrapers.hashtag import *
 from instascrape.scrapers.json_tools import *
 from instascrape.scrapers.login import *
 from instascrape.scrapers.post import *
 from instascrape.scrapers.profile import *
-from instascrape.scrapers.comment import *
\ No newline at end of file
+from instascrape.scrapers.comment import *
+from instascrape.scrapers.location import *
